@@ -68,6 +68,7 @@ enum InternalOp {
   IOpJointMatrixSUMadINTEL = 6128,
   IOpJointMatrixUSMadINTEL = 6129,
   IOpJointMatrixUUMadINTEL = 6130,
+  IOpArithmeticFenceINTEL = 6145,
   IOpTaskSequenceCreateINTEL = 6163,
   IOpTaskSequenceAsyncINTEL = 6164,
   IOpTaskSequenceGetINTEL = 6165,
@@ -76,19 +77,10 @@ enum InternalOp {
   IOpCooperativeMatrixLoadCheckedINTEL = 6193,
   IOpCooperativeMatrixStoreCheckedINTEL = 6194,
   IOpCooperativeMatrixConstructCheckedINTEL = 6195,
-  IOpTypeTaskSequenceINTEL = 6199,
-  IOpClampConvertFToFINTEL = 6216,
-  IOpStochasticRoundFToFINTEL = 6217,
-  IOpClampStochasticRoundFToFINTEL = 6218,
-  IOpClampStochasticRoundFToSINTEL = 6219,
-  IOpCooperativeMatrixLoadOffsetINTEL = 6239,
-  IOpCooperativeMatrixStoreOffsetINTEL = 6240,
-  IOpPredicatedLoadINTEL = 6258,
-  IOpPredicatedStoreINTEL = 6259,
   IOpJointMatrixWorkItemLengthINTEL = 6410,
+  IOpTypeTaskSequenceINTEL = 6199,
   IOpComplexFMulINTEL = 6415,
   IOpComplexFDivINTEL = 6416,
-  IOpClampConvertFToSINTEL = 6424,
   IOpRoundFToTF32INTEL = 6426,
   IOpMaskedGatherINTEL = 6428,
   IOpMaskedScatterINTEL = 6429,
@@ -98,7 +90,6 @@ enum InternalOp {
   IOpConvertHandleToImageINTEL = 6529,
   IOpConvertHandleToSamplerINTEL = 6530,
   IOpConvertHandleToSampledImageINTEL = 6531,
-  IOpFSigmoidINTEL = 6168,
   IOpPrev = OpMax - 2,
   IOpForward
 };
@@ -113,24 +104,16 @@ enum InternalDecoration {
 };
 
 enum InternalCapability {
+  ICapFastCompositeINTEL = 6093,
+  ICapOptNoneINTEL = 6094,
   ICapTokenTypeINTEL = 6112,
   ICapBfloat16ConversionINTEL = 6115,
   ICapabilityJointMatrixINTEL = 6118,
   ICapabilityHWThreadQueryINTEL = 6134,
+  ICapFPArithmeticFenceINTEL = 6144,
   ICapGlobalVariableDecorationsINTEL = 6146,
   ICapabilityTaskSequenceINTEL = 6162,
-  ICapabilitySigmoidINTEL = 6167,
   ICapabilityCooperativeMatrixCheckedInstructionsINTEL = 6192,
-  ICapabilityFloat4E2M1INTEL = 6212,
-  ICapabilityFloat4E2M1CooperativeMatrixINTEL = 6213,
-  ICapabilityFloatConversionsINTEL = 6215,
-  ICapabilityBFloat16ArithmeticINTEL = 6226,
-  ICapabilityAtomicBFloat16AddINTEL = 6255,
-  ICapabilityAtomicBFloat16MinMaxINTEL = 6256,
-  ICapabilityPredicatedIOINTEL = 6257,
-  ICapabilityAtomicInt16CompareExchangeINTEL = 6260,
-  ICapabilityInt16AtomicsINTEL = 6261,
-  ICapabilityAtomicBFloat16LoadStoreINTEL = 6262,
   ICapabilityCooperativeMatrixPrefetchINTEL = 6411,
   ICapabilityComplexFloatMulDivINTEL = 6414,
   ICapabilityTensorFloat32RoundingINTEL = 6425,
@@ -141,11 +124,15 @@ enum InternalCapability {
   ICapabilityJointMatrixBF16ComponentTypeINTEL = 6437,
   ICapabilityJointMatrixPackedInt2ComponentTypeINTEL = 6438,
   ICapabilityJointMatrixPackedInt4ComponentTypeINTEL = 6439,
+  ICapabilityCacheControlsINTEL = 6441,
   ICapabilitySubgroupRequirementsINTEL = 6445,
   ICapabilityBindlessImagesINTEL = 6528
 };
 
+enum InternalFunctionControlMask { IFunctionControlOptNoneINTELMask = 0x10000 };
+
 enum InternalExecutionMode {
+  IExecModeFastCompositeKernelINTEL = 6088,
   IExecModeNamedSubgroupSizeINTEL = 6446,
 };
 
@@ -169,11 +156,6 @@ enum InternalJointMatrixCTI {
   PackedInt4 = 4
 };
 
-enum InternalFPEncoding {
-  FPEncodingFloat4E2M1INTEL = 6214,
-  FPEncodingMax = 0x7fffffff,
-};
-
 enum InternalBuiltIn {
   IBuiltInSubDeviceIDINTEL = 6135,
   IBuiltInGlobalHWThreadIDINTEL = 6136,
@@ -223,6 +205,8 @@ _SPIRV_OP(Op, MaskedScatterINTEL)
 _SPIRV_OP(Capability, TensorFloat32RoundingINTEL)
 _SPIRV_OP(Op, RoundFToTF32INTEL)
 
+_SPIRV_OP(Capability, CacheControlsINTEL)
+
 _SPIRV_OP(Capability, SubgroupRequirementsINTEL)
 
 _SPIRV_OP(Capability, TaskSequenceINTEL)
@@ -236,25 +220,6 @@ _SPIRV_OP(Capability, BindlessImagesINTEL)
 _SPIRV_OP(Op, ConvertHandleToImageINTEL)
 _SPIRV_OP(Op, ConvertHandleToSamplerINTEL)
 _SPIRV_OP(Op, ConvertHandleToSampledImageINTEL)
-
-_SPIRV_OP(Capability, AtomicBFloat16AddINTEL)
-_SPIRV_OP(Capability, AtomicBFloat16MinMaxINTEL)
-
-_SPIRV_OP(Capability, PredicatedIOINTEL)
-_SPIRV_OP(Op, PredicatedLoadINTEL)
-_SPIRV_OP(Op, PredicatedStoreINTEL)
-
-_SPIRV_OP(Capability, SigmoidINTEL)
-_SPIRV_OP(Op, FSigmoidINTEL)
-_SPIRV_OP(Capability, Float4E2M1INTEL)
-_SPIRV_OP(Capability, Float4E2M1CooperativeMatrixINTEL)
-
-_SPIRV_OP(Capability, FloatConversionsINTEL)
-_SPIRV_OP(Op, ClampConvertFToFINTEL)
-_SPIRV_OP(Op, ClampConvertFToSINTEL)
-_SPIRV_OP(Op, StochasticRoundFToFINTEL)
-_SPIRV_OP(Op, ClampStochasticRoundFToFINTEL)
-_SPIRV_OP(Op, ClampStochasticRoundFToSINTEL)
 #undef _SPIRV_OP
 
 constexpr SourceLanguage SourceLanguagePython =
@@ -300,9 +265,12 @@ constexpr SourceLanguage SourceLanguageCPP20 =
 
 constexpr Op OpForward = static_cast<Op>(IOpForward);
 constexpr Op OpTypeTokenINTEL = static_cast<Op>(IOpTypeTokenINTEL);
+constexpr Op OpArithmeticFenceINTEL = static_cast<Op>(IOpArithmeticFenceINTEL);
 constexpr Op OpConvertFToBF16INTEL = static_cast<Op>(IOpConvertFToBF16INTEL);
 constexpr Op OpConvertBF16ToFINTEL = static_cast<Op>(IOpConvertBF16ToFINTEL);
 
+constexpr Decoration DecorationCallableFunctionINTEL =
+    static_cast<Decoration>(IDecCallableFunctionINTEL);
 constexpr Decoration DecorationRuntimeAlignedINTEL =
     static_cast<Decoration>(IDecRuntimeAlignedINTEL);
 constexpr Decoration DecorationHostAccessINTEL =
@@ -314,25 +282,28 @@ constexpr Decoration DecorationImplementInCSRINTEL =
 constexpr Decoration DecorationArgumentAttributeINTEL =
     static_cast<Decoration>(IDecArgumentAttributeINTEL);
 
+constexpr Capability CapabilityFastCompositeINTEL =
+    static_cast<Capability>(ICapFastCompositeINTEL);
+constexpr Capability CapabilityOptNoneINTEL =
+    static_cast<Capability>(ICapOptNoneINTEL);
 constexpr Capability CapabilityTokenTypeINTEL =
     static_cast<Capability>(ICapTokenTypeINTEL);
+constexpr Capability CapabilityFPArithmeticFenceINTEL =
+    static_cast<Capability>(ICapFPArithmeticFenceINTEL);
 constexpr Capability CapabilityBfloat16ConversionINTEL =
     static_cast<Capability>(ICapBfloat16ConversionINTEL);
 constexpr Capability CapabilityGlobalVariableDecorationsINTEL =
     static_cast<Capability>(ICapGlobalVariableDecorationsINTEL);
-constexpr Capability CapabilityBFloat16ArithmeticINTEL =
-    static_cast<Capability>(ICapabilityBFloat16ArithmeticINTEL);
+
+constexpr FunctionControlMask FunctionControlOptNoneINTELMask =
+    static_cast<FunctionControlMask>(IFunctionControlOptNoneINTELMask);
+
+constexpr ExecutionMode ExecutionModeFastCompositeKernelINTEL =
+    static_cast<ExecutionMode>(IExecModeFastCompositeKernelINTEL);
 
 constexpr ExecutionMode ExecutionModeNamedSubgroupSizeINTEL =
     static_cast<ExecutionMode>(IExecModeNamedSubgroupSizeINTEL);
 
-constexpr Capability CapabilityAtomicInt16CompareExchangeINTEL =
-    static_cast<Capability>(ICapabilityAtomicInt16CompareExchangeINTEL);
-constexpr Capability CapabilityInt16AtomicsINTEL =
-    static_cast<Capability>(ICapabilityInt16AtomicsINTEL);
-constexpr Capability CapabilityAtomicBFloat16LoadStoreINTEL =
-    static_cast<Capability>(ICapabilityAtomicBFloat16LoadStoreINTEL);
-
 } // namespace internal
 } // namespace spv
 
